@@ -155,6 +155,12 @@ external __POS__ : string * int * int * int = "%loc_POS"
 There is not equivalent functionality in Base or Stdio at the moment,
 so you need to use [Caml.__POS__] instead"]
 
+external __FUNCTION__ : string = "%loc_FUNCTION"
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+There is not equivalent functionality in Base or Stdio at the moment,
+so you need to use [Caml.__FUNCTION__] instead"]
+
 external __LOC_OF__ : 'a -> string * 'a = "%loc_LOC"
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1067,6 +1073,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.ArrayLabels instead"]
 
+module Atomic = Stdlib.Atomic 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Caml.Atomic instead"]
+
 module Bool = Stdlib.Bool 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1123,6 +1136,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Digest instead"]
 
+module Either = Stdlib.Either 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Caml.Either instead"]
+
 module Ephemeron = Stdlib.Ephemeron 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1343,13 +1363,6 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Set instead"]
 
-module Spacetime = Stdlib.Spacetime 
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-Referring to the stdlib directly is discouraged by Base. You should either
-use the equivalent functionality offered by Base, or if you really want to
-refer to the stdlib, use Caml.Spacetime instead"]
-
 module Stack = Stdlib.Stack 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1413,20 +1426,6 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Caml.Weak instead"]
 
-module Atomic : sig end
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-Referring to the stdlib directly is discouraged by Base. You should either
-use the equivalent functionality offered by Base, or if you really want to
-refer to the stdlib, use Caml.Atomic instead"]
-
-module Either : sig end
-[@@deprecated "\
-[2016-09] this element comes from the stdlib distributed with OCaml.
-Referring to the stdlib directly is discouraged by Base. You should either
-use the equivalent functionality offered by Base, or if you really want to
-refer to the stdlib, use Caml.Either instead"]
-
 exception Not_found
 [@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
